@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 $VERSION = eval $VERSION;
 
 use Acme::CPANAuthors::Register(
@@ -28,10 +28,14 @@ use Acme::CPANAuthors::Register(
     q(ALEXBIO) => q(Alessandro Ghedini),
     q(ALEXM) => q(Alex Muntada),
     q(ALEXMV) => q(Alex Vandiver),
+    q(ALUCAS) => q(Anthony J Lucas),
     q(AMD) => q(AMD OSRC (AMD Operating System Research Center)),
     q(AMIRI) => q(Amiri Barksdale),
+    q(ANAZAWA) => q(Ryo Anazawa),
     q(ANDK) => q(Andreas J. König),
+    q(ANDREFS) => q(André Fernandes dos Santos),
     q(ANDREMAR) => q(Andreas Marienborg),
+    q(ANDREW) => q(Andrew Fresh),
     q(ANDYA) => q(Andy Armstrong),
     q(ANELSON) => q(Andrew Nelson),
     q(ANIRVAN) => q(Anirvan Chatterjee),
@@ -48,6 +52,7 @@ use Acme::CPANAuthors::Register(
     q(ARUNBEAR) => q(Arun Prasaad),
     q(ASH) => q(Ash Berlin),
     q(ASHLEY) => q(Ashley Pond V — 바보 양키스),
+    q(ASKADNA) => q(飛鳥 真一郎),
     q(ASPIERS) => q(Adam Spiers),
     q(ATHOMASON) => q(Adam Thomason),
     q(ATOM) => q(Adam J. Foxson),
@@ -72,15 +77,17 @@ use Acme::CPANAuthors::Register(
     q(BGRAY) => q(Bruce Gray),
     q(BIGPRESH) => q(David Precious),
     q(BINGOS) => q(Chris Williams),
+    q(BJAKUBSKI) => q(Bartosz Jakubski),
     q(BKANEY) => q(Brian Kaney),
+    q(BLABOS) => q(Blabos de Blebe),
     q(BLAIZER) => q(Blaise Roth),
+    q(BLHOTSKY) => q(Brad Lhotsky),
     q(BLUEFEET) => q(Aran Clary Deltac),
     q(BMORROW) => q(Ben Morrow),
     q(BOBTFISH) => q(Tomas Doran),
     q(BOKUTIN) => q(Tomohiro Hosaka),
     q(BOMBARELY) => q(Aureliano Bombarely),
     q(BOOK) => q(Philippe Bruhat (BooK)),
-    q(BOWMANBS) => q(Brad Bowman),
     q(BPHILLIPS) => q(Brian Phillips),
     q(BRIANG) => q(brian greenfield),
     q(BRICAS) => q(Brian Cassidy),
@@ -88,6 +95,7 @@ use Acme::CPANAuthors::Register(
     q(BRUNOV) => q(Bruno Vecchi),
     q(BTROTT) => q(Benjamin Trott),
     q(BUNDACIA) => q(Trevor Little),
+    q(BVR) => q(Roman Hubáček),
     q(CADAVIS) => q(Chad A Davis),
     q(CAPTTOFU) => q(Patrick Galbraith),
     q(CARWASH) => q(Marcus Smith),
@@ -107,6 +115,7 @@ use Acme::CPANAuthors::Register(
     q(CJM) => q(Christopher J. Madsen),
     q(CKRAS) => q(Christiaan Kras),
     q(CLAESJAC) => q(Claes Jakobsson),
+    q(CLAIRVY) => q(永谷 真一郎),
     q(CLKAO) => q(Chia-liang Kao (高嘉良)),
     q(CMCKAY) => q(Christopher Mckay),
     q(CNANGEL) => q(李俊良),
@@ -118,11 +127,13 @@ use Acme::CPANAuthors::Register(
     q(CRENZ) => q(Christian Renz),
     q(CROMEDOME) => q(Jason A. Crome),
     q(CRUX) => q(Vladimir Lettiev),
+    q(CUBABIT) => q(Pete Smith),
     q(CVEGA) => q(Casey Vega),
     q(DAGOLDEN) => q(David Golden),
     q(DAM) => q(Дамян Иванов),
     q(DAMOG) => q(David Moreno),
     q(DAMS) => q(Damien Krotkine),
+    q(DANAJ) => q(Dana Jacobsen),
     q(DANBOO) => q(Daniel B. Boorstein),
     q(DANIEL) => q(Dan Sully),
     q(DANIELM) => q(Daniel Mascarenhas),
@@ -165,8 +176,10 @@ use Acme::CPANAuthors::Register(
     q(DROLSKY) => q(Dave Rolsky),
     q(DRTECH) => q(Clinton Gormley),
     q(DRUOSO) => q(Daniel Ruoso),
+    q(DRUXA) => q(Андрей Мищенко),
     q(DUELAFN) => q(Dean Serenevy),
     q(DUFF) => q(Jonathan Scott Duff),
+    q(DUKKIE) => q(小塚昌隆),
     q(DUNCAND) => q(Darren Duncan),
     q(DUNCS) => q(Duncan Ferguson),
     q(DWHEELER) => q(David E. Wheeler),
@@ -194,6 +207,7 @@ use Acme::CPANAuthors::Register(
     q(FRANKS) => q(Frank Sheiness),
     q(FREW) => q(Arthur Axel "fREW" Schmidt),
     q(FRIED) => q(Jason Fried),
+    q(FRIEDO) => q(Mike Friedman),
     q(FRODWITH) => q(Paul Driver),
     q(FROGGS) => q(Tobias Leich),
     q(FVOX) => q(Junior Moraes),
@@ -206,6 +220,7 @@ use Acme::CPANAuthors::Register(
     q(GERHARD) => q(Gerhard Gossen),
     q(GETTY) => q(Torsten Raudssus),
     q(GFUJI) => q(藤 吾郎),
+    q(GGOLDBACH) => q(Gregor Goldbach),
     q(GPHAT) => q(Cory G Watson),
     q(GRAF) => q(Bernhard Graf),
     q(GRANTM) => q(Grant McLean),
@@ -223,6 +238,7 @@ use Acme::CPANAuthors::Register(
     q(HANENKAMP) => q(Andrew Sterling Hanenkamp),
     q(HATENA) => q(はてな (Hatena, Inc.)),
     q(HAWK) => q(Jesper Dangaard Brouer),
+    q(HDAICHI) => q(広木　大地),
     q(HDP) => q(Hans Dieter Pearcey),
     q(HERNAN) => q(Hernan Lopes),
     q(HIDE) => q(Hideo Kimura),
@@ -234,6 +250,7 @@ use Acme::CPANAuthors::Register(
     q(HIROSE) => q(HIROSE Masaaki),
     q(HMA) => q(Henning Manske),
     q(HSW) => q(Sergey Homenkow),
+    q(IBUDAI) => q(Ioana Budai),
     q(ICERIDER) => q(Philip Monsen),
     q(IDOPEREL) => q(עידו פרלמוטר (Ido Perlmuter)),
     q(IKEBE) => q(IKEBE Tomohiro),
@@ -247,6 +264,8 @@ use Acme::CPANAuthors::Register(
     q(JAITKEN) => q(James Aitken),
     q(JAKOBI) => q(Peter Jakobi),
     q(JALDHAR) => q(જલધર હ. વ્યાસ),
+    q(JAMTUR) => q(James Turnbull),
+    q(JANDREW) => q(Jed Lund),
     q(JASONJAYR) => q(Jason Rodrigues),
     q(JASONMAY) => q(Jason May),
     q(JAWNSY) => q(Jonathan Yu),
@@ -256,6 +275,7 @@ use Acme::CPANAuthors::Register(
     q(JERI) => q(Jeremiah Mahler),
     q(JESSE) => q(Jesse Vincent),
     q(JETTERO) => q(Paul Miller),
+    q(JFITZ) => q(James FitzGibbon),
     q(JFRIED) => q(Jan Gehring),
     q(JGOULAH) => q(John Goulah),
     q(JHANNAH) => q(Jay Hannah),
@@ -268,9 +288,11 @@ use Acme::CPANAuthors::Register(
     q(JLAVALLEE) => q(Jeff Lavallee),
     q(JMATES) => q(Jeremy Mates),
     q(JMCNAMARA) => q(John McNamara),
+    q(JOHND) => q(John Drago),
     q(JONALLEN) => q(Jon Allen),
     q(JONASBN) => q(jonasbn),
     q(JQUELIN) => q(Jérôme Quelin),
+    q(JRIDEOUT) => q(Jacob R Rideout),
     q(JROBINSON) => q(Jess Robinson),
     q(JROCKWAY) => q(Jonathan Rockway),
     q(JSHIRLEY) => q(J. Shirley),
@@ -294,8 +316,9 @@ use Acme::CPANAuthors::Register(
     q(KIMBREL) => q(Sam Kimbrel),
     q(KIMOTO) => q(Yuki Kimoto),
     q(KITANO) => q(dann),
+    q(KIWANAMI) => q(Masashi Sakurai),
     q(KJETILK) => q(Kjetil Kjernsmo),
-    q(KMCGRATH) => q(Kevin C. McGrath),
+    q(KMCGRATH) => q(Kevin McGrath),
     q(KMX) => q(kmx),
     q(KONOBI) => q(Scott McWhirter),
     q(KOORCHIK) => q(Viktor Tuskyi),
@@ -309,22 +332,28 @@ use Acme::CPANAuthors::Register(
     q(KWILLIAMS) => q(Ken Williams),
     q(LACKITA) => q(Colin Williams),
     q(LBROCARD) => q(Léon Brocard),
+    q(LECSTOR) => q(Jason Galea),
     q(LEEDO) => q(Lee Aylward),
+    q(LENJAFFE) => q(Len Jaffe),
     q(LEONT) => q(Leon Timmermans),
     q(LESPEA) => q(Adam Lesperance),
     q(LETO) => q(Jonathan Leto),
+    q(LICHTKIND) => q(Herbert Breunung),
     q(LIFEGUARD) => q(Mike.lifeguard),
     q(LIMAONE) => q(LIMAONE),
     q(LKUNDRAK) => q(Lubomir Rintel),
     q(LLAP) => q(Leo Lapworth),
+    q(LOGIE) => q(Logan Bell),
     q(LRR) => q(Luis M Rodríguez-R),
     q(LUKEC) => q(Luke Closs),
     q(MADCAT) => q(Ben van Staveren),
     q(MAESTRO) => q(Geoffrey Darling),
     q(MAKAMAKA) => q(Makamaka Hannyaharamitu),
     q(MALA) => q(ma la),
+    q(MALLEN) => q(Mark Allen),
     q(MANNI) => q(Manni Heumann),
     q(MARCEL) => q(Marcel Grünauer),
+    q(MARCUSSEN) => q(Eldar Marcussen),
     q(MARKF) => q(Mark Fowler),
     q(MARKSTOS) => q(Mark Stosberg),
     q(MAROS) => q(Maroš Kollár),
@@ -332,6 +361,7 @@ use Acme::CPANAuthors::Register(
     q(MASAKI) => q(Masaki Nakagawa),
     q(MASARTZ) => q(Masaru Hoshino),
     q(MATEU) => q(Mateu X. Hunter),
+    q(MATTDEES) => q(Matthew Dees),
     q(MATTK) => q(Matt Koscica),
     q(MATTN) => q(Yasuhiro Matsumoto),
     q(MATTP) => q(Matthew Phillips),
@@ -344,6 +374,7 @@ use Acme::CPANAuthors::Register(
     q(MDIETRICH) => q(Matthias Dietrich),
     q(MDOM) => q(Mario Domgörgen),
     q(MEETTYA) => q(Карпич Дмитрий),
+    q(MELEZHIK) => q(melezhik),
     q(MELO) => q(Pedro Melo),
     q(MENDEL) => q(Norbert Buchmüller),
     q(MERIXZON) => q(Magnus Erixzon),
@@ -370,6 +401,7 @@ use Acme::CPANAuthors::Register(
     q(MORIYA) => q(MORIYA Masaki (守屋 雅樹)),
     q(MOSHEN) => q(Colin Kennedy),
     q(MOTEMEN) => q(モテメン),
+    q(MRA) => q(Mark Atwood),
     q(MRAMBERG) => q(Marcus Ramberg),
     q(MRGRIPH) => q(Dmitriy V. Simonov),
     q(MROZ) => q(Ray Mroz),
@@ -393,7 +425,6 @@ use Acme::CPANAuthors::Register(
     q(NOTBENH) => q(ben hengst),
     q(NPEREZ) => q(Nicholas Perez),
     q(NPLATONOV) => q(Nickolay Platonov),
-    q(NPW) => q(Nick Stokoe),
     q(NUFFIN) => q(יובל קוג'מן (Yuval Kogman)),
     q(NWELLNHOF) => q(Nick Wellnhofer),
     q(OALDERS) => q(Olaf Alders),
@@ -411,10 +442,12 @@ use Acme::CPANAuthors::Register(
     q(PBOYD) => q(Paul Boyd),
     q(PDCAWLEY) => q(Piers Cawley),
     q(PDONELAN) => q(Patrick Donelan),
+    q(PEK) => q(Petr Kletečka),
     q(PEPL) => q(Michael Kröll),
     q(PERIGRIN) => q(Chris Prather),
     q(PERLER) => q(Moritz Onken),
     q(PERLISH) => q(seyed hadi hosseini),
+    q(PERLOVER) => q(Perlover Developer),
     q(PETDANCE) => q(Andy Lester),
     q(PFISCHER) => q(Pablo Fischer),
     q(PHAYLON) => q(Robert 'phaylon' Sedlacek),
@@ -427,6 +460,7 @@ use Acme::CPANAuthors::Register(
     q(PMOONEY) => q(Paul Mooney),
     q(PMORCH) => q(Peter Valdemar Mørch),
     q(PNU) => q(Panu Ervamaa),
+    q(POLETTIX) => q(Flavio Poletti),
     q(POTYL) => q(Emmanuel Rodriguez),
     q(PROFANTER) => q(Stefan Profanter),
     q(PSHANGOV) => q(Peter Shangov),
@@ -434,6 +468,7 @@ use Acme::CPANAuthors::Register(
     q(PVANDE) => q(Pieter van de Bruggen),
     q(PWES) => q(Przemysław Wesołek),
     q(QIUHW) => q(邱红文),
+    q(RAPHINK) => q(Raphaël Pinson),
     q(RBO) => q(Robert Bohne),
     q(RBUELS) => q(Robert Buels),
     q(RCAPUTO) => q(Rocco Caputo),
@@ -444,7 +479,6 @@ use Acme::CPANAuthors::Register(
     q(RGE) => q(Robin Edwards),
     q(RHESA) => q(Rhesa Rozendaal),
     q(RHOELZ) => q(Rob Hoelz),
-    q(RIBASUSHI) => q(Peter Rabbitson),
     q(RINTARO) => q(Rintaro Ishizaki),
     q(RIZEN) => q(JT Smith),
     q(RJBS) => q(Ricardo SIGNES),
@@ -464,7 +498,7 @@ use Acme::CPANAuthors::Register(
     q(RWSTAUNER) => q(Randy Stauner),
     q(SABECK) => q(Scott Beck),
     q(SALVA) => q(Salvador Fandiño García),
-    q(SANKO) => q(Sanko Robinson),
+    q(SANKO) => q(ロビンソン三興),
     q(SAPER) => q(Sébastien Aperghis-Tramoni),
     q(SARGIE) => q(Peter Sergeant),
     q(SARTAK) => q(Shawn M Moore),
@@ -477,8 +511,8 @@ use Acme::CPANAuthors::Register(
     q(SDEN) => q(Λόρδος Σπύρος Δεναξάς),
     q(SDT) => q(Stephen Thirlwall),
     q(SEKIMURA) => q(Masayoshi Sekimura),
+    q(SFOSSE) => q(Stéphane FOSSE),
     q(SGRAHAM) => q(Sam Graham),
-    q(SHABBLE) => q(Tom Feist),
     q(SHANTANU) => q(Shantanu Bhadoria),
     q(SHARIFULN) => q(Анатолий Шарифулин),
     q(SHARYANTO) => q(Steven Haryanto),
@@ -487,11 +521,13 @@ use Acme::CPANAuthors::Register(
     q(SHELLING) => q(許家瑋),
     q(SHERWIN) => q(Sherwin Daganato),
     q(SHLOMIF) => q(Shlomi Fish),
+    q(SHOOTNIX) => q(Alexander Ponomarev),
     q(SHUFF) => q(Steve Huff),
     q(SIDD) => q(Siddhartha Basu),
     q(SILASMONK) => q(Nicholas Bamber),
     q(SIMONW) => q(Simon Wistow),
     q(SIXAPART) => q(Six Apart Ltd.),
+    q(SKNPP) => q(Sebastian Knapp),
     q(SLU) => q(Søren Lund),
     q(SMUELLER) => q(Steffen Müller),
     q(SPARKY) => q(Przemysław Iskra),
@@ -551,8 +587,10 @@ use Acme::CPANAuthors::Register(
     q(VOJ) => q(Jakob Voß),
     q(VOVKASM) => q(Vladimir Timofeev),
     q(VTI) => q(Вячеслав Тихановский),
+    q(VTRONE) => q(Stéphane),
     q(VVU) => q(Alex White (wu)),
     q(WARRINGD) => q(David Warring),
+    q(WARTHURT) => q(Wayne A. Arthurton),
     q(WINTER) => q(Becca Turner),
     q(WOLDRICH) => q(Magnus Woldrich),
     q(WOLFSAGE) => q(Matthew Horsfall (alh)),
@@ -576,6 +614,7 @@ use Acme::CPANAuthors::Register(
     q(YKO) => q(Yaroslav Korshak),
     q(YOSHIMI) => q(Keiji Yoshimi),
     q(YSASAKI) => q(Yoshihiro Sasaki),
+    q(YSYROTA) => q(Юрій Сирота),
     q(YUSUKEBE) => q(Yusuke Wada),
     q(ZAG) => q(Zahatski Aliaksandr),
     q(ZAKAME) => q(Zak B. Elep),
@@ -665,7 +704,7 @@ L<http://search.cpan.org/dist/Acme-CPANAuthors-GitHub/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2011 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2010-2012 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
